==> aws-java-sdk-1.3.8-sources.jar: com/amazonaws/services/ec2/model/transform/RouteTableStaxUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Route Table StAX Unmarshaller
 */
public class RouteTableStaxUnmarshaller implements Unmarshaller<RouteTable, StaxUnmarshallerContext> {

    public RouteTable unmarshall(StaxUnmarshallerContext context) throws Exception {
        RouteTable routeTable = new RouteTable();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        
        if (context.isStartOfDocument()) targetDepth += 1;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return routeTable;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("routeTableId", targetDepth)) {
                    routeTable.setRouteTableId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("vpcId", targetDepth)) {
                    routeTable.setVpcId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("routeSet/item", targetDepth)) {
                    routeTable.getRoutes().add(RouteStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("associationSet/item", targetDepth)) {
                    routeTable.getAssociations().add(RouteTableAssociationStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("tagSet/item", targetDepth)) {
                    routeTable.getTags().add(TagStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return routeTable;
                }
            }
        }
    }

    private static RouteTableStaxUnmarshaller instance;
    public static RouteTableStaxUnmarshaller getInstance() {
        if (instance == null) instance = new RouteTableStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.3.21-sources.jar: com/amazonaws/services/ec2/model/transform/RouteTableStaxUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Route Table StAX Unmarshaller
 */
public class RouteTableStaxUnmarshaller implements Unmarshaller<RouteTable, StaxUnmarshallerContext> {

    public RouteTable unmarshall(StaxUnmarshallerContext context) throws Exception {
        RouteTable routeTable = new RouteTable();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        
        if (context.isStartOfDocument()) targetDepth += 1;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return routeTable;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("routeTableId", targetDepth)) {
                    routeTable.setRouteTableId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("vpcId", targetDepth)) {
                    routeTable.setVpcId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("routeSet/item", targetDepth)) {
                    routeTable.getRoutes().add(RouteStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("associationSet/item", targetDepth)) {
                    routeTable.getAssociations().add(RouteTableAssociationStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("tagSet/item", targetDepth)) {
                    routeTable.getTags().add(TagStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("propagatingVgwSet/item", targetDepth)) {
                    routeTable.getPropagatingVgws().add(PropagatingVgwStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("propagatedRouteSet/item", targetDepth)) {
                    routeTable.getPropagatedRoutes().add(PropagatedRouteStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return routeTable;
                }
            }
        }
    }

    private static RouteTableStaxUnmarshaller instance;
    public static RouteTableStaxUnmarshaller getInstance() {
        if (instance == null) instance = new RouteTableStaxUnmarshaller();
        return instance;
    }
}
